@@ -188,31 +188,25 @@ and will not include the description value of the CompletionItems.
 
 **Patched argparse functions**
 
-argparse._ActionsContainer.add_argument - adds arguments related to tab
-                                          completion and enables nargs range
-                                          parsing See _add_argument_wrapper for
-                                          more details on these argument
+``argparse._ActionsContainer.add_argument`` - adds arguments related to tab
+completion and enables nargs range parsing. See _add_argument_wrapper for
+more details on these arguments.
 
-argparse.ArgumentParser._get_nargs_pattern - adds support to for nargs ranges
-                                             See _get_nargs_pattern_wrapper for
-                                             more details
+``argparse.ArgumentParser._get_nargs_pattern`` - adds support to for nargs
+ranges. See _get_nargs_pattern_wrapper for more details.
 
-argparse.ArgumentParser._match_argument - adds support to for nargs ranges See
-                                          _match_argument_wrapper for more
-                                          details
+``argparse.ArgumentParser._match_argument`` - adds support to for nargs ranges.
+See _match_argument_wrapper for more details.
 """
 
 import argparse
 import re
 import sys
 # noinspection PyUnresolvedReferences,PyProtectedMember
-from argparse import ZERO_OR_MORE, ONE_OR_MORE, ArgumentError, _
+from argparse import ONE_OR_MORE, ZERO_OR_MORE, ArgumentError, _
 from typing import Callable, Optional, Tuple, Type, Union
 
-from . import ansi
-
-# Used in nargs ranges to signify there is no maximum
-INFINITY = float('inf')
+from . import ansi, constants
 
 ############################################################################################################
 # The following are names of custom argparse argument attributes added by cmd2
@@ -236,7 +230,7 @@ def generate_range_error(range_min: int, range_max: Union[int, float]) -> str:
     """Generate an error message when the the number of arguments provided is not within the expected range"""
     err_str = "expected "
 
-    if range_max == INFINITY:
+    if range_max == constants.INFINITY:
         err_str += "at least {} argument".format(range_min)
 
         if range_min != 1:
@@ -387,7 +381,7 @@ def _add_argument_wrapper(self, *args,
           See the header of this file for more information
 
     :return: the created argument action
-    :raises ValueError on incorrect parameter usage
+    :raises: ValueError on incorrect parameter usage
     """
     # Verify consistent use of arguments
     choices_callables = [choices_function, choices_method, completer_function, completer_method]
@@ -407,11 +401,11 @@ def _add_argument_wrapper(self, *args,
 
             # Handle 1-item tuple by setting max to INFINITY
             if len(nargs) == 1:
-                nargs = (nargs[0], INFINITY)
+                nargs = (nargs[0], constants.INFINITY)
 
             # Validate nargs tuple
             if len(nargs) != 2 or not isinstance(nargs[0], int) or \
-                    not (isinstance(nargs[1], int) or nargs[1] == INFINITY):
+                    not (isinstance(nargs[1], int) or nargs[1] == constants.INFINITY):
                 raise ValueError('Ranged values for nargs must be a tuple of 1 or 2 integers')
             if nargs[0] >= nargs[1]:
                 raise ValueError('Invalid nargs range. The first value must be less than the second')
@@ -432,10 +426,10 @@ def _add_argument_wrapper(self, *args,
                     nargs_range = None
                 else:
                     nargs_adjusted = argparse.ZERO_OR_MORE
-                    if range_max == INFINITY:
+                    if range_max == constants.INFINITY:
                         # No range needed since (0, INFINITY) is just argparse.ZERO_OR_MORE
                         nargs_range = None
-            elif range_min == 1 and range_max == INFINITY:
+            elif range_min == 1 and range_max == constants.INFINITY:
                 nargs_adjusted = argparse.ONE_OR_MORE
 
                 # No range needed since (1, INFINITY) is just argparse.ONE_OR_MORE
@@ -487,7 +481,7 @@ def _get_nargs_pattern_wrapper(self, action) -> str:
     # Wrapper around ArgumentParser._get_nargs_pattern behavior to support nargs ranges
     nargs_range = getattr(action, ATTR_NARGS_RANGE, None)
     if nargs_range is not None:
-        if nargs_range[1] == INFINITY:
+        if nargs_range[1] == constants.INFINITY:
             range_max = ''
         else:
             range_max = nargs_range[1]
@@ -712,7 +706,7 @@ class Cmd2HelpFormatter(argparse.RawTextHelpFormatter):
         nargs_range = getattr(action, ATTR_NARGS_RANGE, None)
 
         if nargs_range is not None:
-            if nargs_range[1] == INFINITY:
+            if nargs_range[1] == constants.INFINITY:
                 range_str = '{}+'.format(nargs_range[0])
             else:
                 range_str = '{}..{}'.format(nargs_range[0], nargs_range[1])
